@@ -287,18 +287,6 @@ class Model:
                 constantvalues.append(variable.value)
         return constantvalues
 
-    @property
-    def variable(self, name):
-        """
-        Documentation
-        """
-        result = 'Variable "'+name+'" not found.'
-        for variable in self.__variables:
-            if variable.name == name:
-                result = variable
-                break
-        return variable
-
     @property
     def mergedcells(self):
         """
@@ -316,7 +304,7 @@ class Model:
         """
         return self.__variables
 
-    @property
+
     def variable(self, name):
         """
         Documentation
@@ -364,7 +352,9 @@ class Model:
         tables = {}
         for name in self.variablenames:
             if 'tbl' in name:
-                positions.update({name:variable(name).row})
+                row = self.variable(name).row
+                print(self.variable(name).row)
+                positions.update({name:self.variable(name).row})
 
         for name in self.variablenames:
             if 'tbl' in name:
@@ -405,6 +395,8 @@ class Model:
                 for variable in self.variables:
                     if variable.row >
     """
+        return None
+
     def past_in_worksheet(self,worksheet):
         """
         Documentation
